"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const reg_suit_util_1 = require("reg-suit-util");
const tiny_commit_walker_1 = require("tiny-commit-walker");
const create_comment_1 = require("./create-comment");
const gh_gql_client_1 = require("./gh-gql-client");
class GhApiNotifierPlugin {
    constructor() {
        this.name = "reg-notify-github-with-api-plugin";
    }
    init(config) {
        this._logger = config.logger;
        this._owner = config.options.owner;
        this._repository = config.options.repository;
        this._githubUrl = config.options.githubUrl || "https://github.com";
        this._token = config.options.privateToken;
        this._repo = new tiny_commit_walker_1.Repository(path.join(reg_suit_util_1.fsUtil.prjRootDir(".git"), ".git"));
    }
    notify(params) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this._token) {
                this._logger.warn("GitHub private access token is needed. Check plugins config.");
                return;
            }
            if (!this._owner) {
                this._logger.warn("'owner' parameter is needed. Check plugins config.");
                return;
            }
            if (!this._repository) {
                this._logger.warn("'repository' parameter is needed. Check plugins config.");
                return;
            }
            const head = this._repo.readHeadSync();
            const commentBody = create_comment_1.createCommentBody({
                reportUrl: params.reportUrl,
                passedItemsCount: params.comparisonResult.passedItems.length,
                failedItemsCount: params.comparisonResult.diffItems.length,
                newItemsCount: params.comparisonResult.newItems.length,
                deletedItemsCount: params.comparisonResult.deletedItems.length,
            });
            const client = new gh_gql_client_1.GhGqlClient(this._token, this._githubUrl);
            if (head.type !== "branch" || !head.branch) {
                this._logger.warn("Can't detect branch name.");
                return;
            }
            yield client.postCommentToPr({
                owner: this._owner,
                repository: this._repository,
                branchName: head.branch.name,
                body: commentBody,
            });
        });
    }
}
exports.GhApiNotifierPlugin = GhApiNotifierPlugin;
//# sourceMappingURL=gh-api-notifier-plugin.js.map